summaryrefslogtreecommitdiff
path: root/configs/profile-openrc
diff options
context:
space:
mode:
authorDavid P <megver83@parabola.nu>2018-05-16 21:08:49 -0400
committerDavid P <megver83@parabola.nu>2018-05-16 21:27:46 -0400
commit765756ae126d57735c22d59a7c1242f01443921e (patch)
treec5d5f3e7979f5a0098e7294d1e8dbae3aa71c562 /configs/profile-openrc
parentff5f93347993bfdb6c58746baee006dbad7a3dd8 (diff)
modify entire source according to archiso32
and remove unused configs/talkingparabola-X11 Signed-off-by: David P <megver83@parabola.nu>
Diffstat (limited to 'configs/profile-openrc')
-rw-r--r--configs/profile-openrc/airootfs/etc/conf.d/agetty.tty13
-rw-r--r--configs/profile-openrc/airootfs/etc/conf.d/hostname1
-rw-r--r--configs/profile-openrc/airootfs/etc/fstab (renamed from configs/profile-openrc/root-image/etc/fstab)0
-rwxr-xr-xconfigs/profile-openrc/airootfs/etc/init.d/pacman-init (renamed from configs/profile-openrc/root-image/etc/init.d/pacman-init)17
-rw-r--r--configs/profile-openrc/airootfs/etc/locale.conf (renamed from configs/profile-openrc/root-image/etc/locale.conf)0
-rw-r--r--configs/profile-openrc/airootfs/etc/motd (renamed from configs/profile-openrc/root-image/etc/motd)9
-rw-r--r--configs/profile-openrc/airootfs/etc/pam.d/su (renamed from configs/profile-openrc/root-image/etc/pam.d/su)0
-rw-r--r--configs/profile-openrc/airootfs/etc/sudoers.d/g_wheel (renamed from configs/profile-openrc/root-image/etc/sudoers.d/g_wheel)0
-rwxr-xr-xconfigs/profile-openrc/airootfs/root/.automated_script.sh (renamed from configs/profile-openrc/root-image/root/.automated_script.sh)0
-rw-r--r--configs/profile-openrc/airootfs/root/.zlogin (renamed from configs/profile-openrc/root-image/root/.zlogin)0
-rwxr-xr-xconfigs/profile-openrc/airootfs/root/customize_airootfs.sh41
-rw-r--r--configs/profile-openrc/airootfs/root/install.txt2
-rw-r--r--configs/profile-openrc/aitab3
-rwxr-xr-xconfigs/profile-openrc/build.sh144
-rw-r--r--configs/profile-openrc/mkinitcpio.conf2
-rw-r--r--configs/profile-openrc/packages.both1
-rw-r--r--configs/profile-openrc/root-image/etc/conf.d/agetty.tty111
-rw-r--r--configs/profile-openrc/root-image/etc/conf.d/hostname2
-rw-r--r--configs/profile-openrc/root-image/etc/udev/rules.d/81-dhcpcd.rules1
-rwxr-xr-xconfigs/profile-openrc/root-image/root/customize_root_image.sh39
-rw-r--r--configs/profile-openrc/root-image/root/network.html191
21 files changed, 149 insertions, 318 deletions
diff --git a/configs/profile-openrc/airootfs/etc/conf.d/agetty.tty1 b/configs/profile-openrc/airootfs/etc/conf.d/agetty.tty1
new file mode 100644
index 0000000..997909c
--- /dev/null
+++ b/configs/profile-openrc/airootfs/etc/conf.d/agetty.tty1
@@ -0,0 +1,3 @@
+baud="38400"
+term_type="linux"
+agetty_options="--autologin root --noclear"
diff --git a/configs/profile-openrc/airootfs/etc/conf.d/hostname b/configs/profile-openrc/airootfs/etc/conf.d/hostname
new file mode 100644
index 0000000..5a912cd
--- /dev/null
+++ b/configs/profile-openrc/airootfs/etc/conf.d/hostname
@@ -0,0 +1 @@
+hostname="parabolaiso"
diff --git a/configs/profile-openrc/root-image/etc/fstab b/configs/profile-openrc/airootfs/etc/fstab
index e69de29..e69de29 100644
--- a/configs/profile-openrc/root-image/etc/fstab
+++ b/configs/profile-openrc/airootfs/etc/fstab
diff --git a/configs/profile-openrc/root-image/etc/init.d/pacman-init b/configs/profile-openrc/airootfs/etc/init.d/pacman-init
index b610683..b646e52 100755
--- a/configs/profile-openrc/root-image/etc/init.d/pacman-init
+++ b/configs/profile-openrc/airootfs/etc/init.d/pacman-init
@@ -1,5 +1,5 @@
#!/usr/bin/openrc-run
-# Copyright (C) 2017 Parabola Project
+# Copyright (C) 2018 Parabola Project
# Copyright (C) Gentoo Foundation
# Distributed under the terms of the GNU General Public License v2
@@ -12,20 +12,19 @@ depend() {
start() {
# Check that there's no keyring, if there isn't, create one
- # in the background for a faster boot
if [ ! -d /etc/pacman.d/gnupg ]; then
- ebegin "Starting Pacman keyring"
- pacman-key --init &> /dev/null &&
- pacman-key --populate archlinux parabola &> /dev/null
+ ebegin "Initializing Pacman keyring"
+ pacman-key --init &> /dev/null &&
+ pacman-key --populate ${KEYS} &> /dev/null
else
- ebegin "Pacman keyring already started"
+ ebegin "Pacman keyring already started"
fi
}
-
+
stop() {
# If there's a keyring, delete it
if [ -d /etc/pacman.d/gnupg ]; then
- ebegin "Stoping Pacman keyring"
- rm -rf /etc/pacman.d/gnupg
+ ebegin "Stoping Pacman keyring"
+ rm -rf /etc/pacman.d/gnupg
fi
}
diff --git a/configs/profile-openrc/root-image/etc/locale.conf b/configs/profile-openrc/airootfs/etc/locale.conf
index 01ec548..01ec548 100644
--- a/configs/profile-openrc/root-image/etc/locale.conf
+++ b/configs/profile-openrc/airootfs/etc/locale.conf
diff --git a/configs/profile-openrc/root-image/etc/motd b/configs/profile-openrc/airootfs/etc/motd
index a126999..6742f6f 100644
--- a/configs/profile-openrc/root-image/etc/motd
+++ b/configs/profile-openrc/airootfs/etc/motd
@@ -1,14 +1,17 @@
===============================================================================
- Parabola live media _DATE_
+ Parabola GNU/Linux-libre live media _DATE_
To install Parabola, the system must be connected to the internet.
For instructions, enter this command:
- lynx network.html
+ less install.txt
Press the function keys while holding Alt to switch virtual terminals.
- This allows entering commands without closing lynx.
+ This allows entering commands without closing less.
+
+ For installation itself, enter this command:
+ ./install.sh
===============================================================================

diff --git a/configs/profile-openrc/root-image/etc/pam.d/su b/configs/profile-openrc/airootfs/etc/pam.d/su
index a291042..a291042 100644
--- a/configs/profile-openrc/root-image/etc/pam.d/su
+++ b/configs/profile-openrc/airootfs/etc/pam.d/su
diff --git a/configs/profile-openrc/root-image/etc/sudoers.d/g_wheel b/configs/profile-openrc/airootfs/etc/sudoers.d/g_wheel
index 8c45359..8c45359 100644
--- a/configs/profile-openrc/root-image/etc/sudoers.d/g_wheel
+++ b/configs/profile-openrc/airootfs/etc/sudoers.d/g_wheel
diff --git a/configs/profile-openrc/root-image/root/.automated_script.sh b/configs/profile-openrc/airootfs/root/.automated_script.sh
index fb106da..fb106da 100755
--- a/configs/profile-openrc/root-image/root/.automated_script.sh
+++ b/configs/profile-openrc/airootfs/root/.automated_script.sh
diff --git a/configs/profile-openrc/root-image/root/.zlogin b/configs/profile-openrc/airootfs/root/.zlogin
index f598e43..f598e43 100644
--- a/configs/profile-openrc/root-image/root/.zlogin
+++ b/configs/profile-openrc/airootfs/root/.zlogin
diff --git a/configs/profile-openrc/airootfs/root/customize_airootfs.sh b/configs/profile-openrc/airootfs/root/customize_airootfs.sh
new file mode 100755
index 0000000..f52ac11
--- /dev/null
+++ b/configs/profile-openrc/airootfs/root/customize_airootfs.sh
@@ -0,0 +1,41 @@
+#!/bin/bash
+
+set -e -u
+
+sed -i 's/#\(en_US\.UTF-8\)/\1/' /etc/locale.gen
+locale-gen
+
+ln -sf /usr/share/zoneinfo/UTC /etc/localtime
+
+usermod -s /usr/bin/zsh root
+cp -aT /etc/skel/ /root/
+chmod 700 /root
+
+sed -i 's/#\(PermitRootLogin \).\+/\1yes/' /etc/ssh/sshd_config
+sed -i "s/#Server/Server/g" /etc/pacman.d/mirrorlist
+
+sed -i 's/#\(HandleSuspendKey=\)suspend/\1ignore/' /etc/elogind/logind.conf
+sed -i 's/#\(HandleHibernateKey=\)hibernate/\1ignore/' /etc/elogind/logind.conf
+sed -i 's/#\(HandleLidSwitch=\)suspend/\1ignore/' /etc/elogind/logind.conf
+
+case $(uname -m) in
+ x86_64) echo 'KEYS="archlinux parabola"' > /etc/conf.d/pacman-init
+ ;;
+ i686) echo 'KEYS="archlinux archlinux32 parabola"' > /etc/conf.d/pacman-init
+ ;;
+esac
+
+useradd -m -p "" -g users -G "adm,audio,floppy,log,network,scanner,storage,optical,power,wheel,disk,sys" -s /usr/bin/zsh parabola
+
+services=(NetworkManager
+ elogind
+ alsasound
+ dbus
+ haveged
+ pacman-init)
+
+for s in ${services[@]}; do
+ rc-update add $s default
+done
+
+sed -i "s/_DATE_/$(date +%Y.%m.%d)/" /etc/motd
diff --git a/configs/profile-openrc/airootfs/root/install.txt b/configs/profile-openrc/airootfs/root/install.txt
new file mode 100644
index 0000000..a594b97
--- /dev/null
+++ b/configs/profile-openrc/airootfs/root/install.txt
@@ -0,0 +1,2 @@
+View this installation guide online at
+https://wiki.parabola.nu/Installation_Guide
diff --git a/configs/profile-openrc/aitab b/configs/profile-openrc/aitab
deleted file mode 100644
index b7e9a17..0000000
--- a/configs/profile-openrc/aitab
+++ /dev/null
@@ -1,3 +0,0 @@
-# <img> <mnt> <arch> <sfs_comp> <fs_type> <fs_size>
-root-image / i686 xz ext4 50%
-root-image / x86_64 xz ext4 50%
diff --git a/configs/profile-openrc/mkinitcpio.conf b/configs/profile-openrc/mkinitcpio.conf
index fc2572b..9448579 100644
--- a/configs/profile-openrc/mkinitcpio.conf
+++ b/configs/profile-openrc/mkinitcpio.conf
@@ -1,3 +1,3 @@
MODULES="loop"
-HOOKS="base udev memdisk parabolaiso_shutdown parabolaiso parabolaiso_loop_mnt parabolaiso_pxe_common parabolaiso_pxe_nbd parabolaiso_pxe_http parabolaiso_pxe_nfs parabolaiso_kms block pcmcia filesystems keyboard"
+HOOKS=(base udev memdisk parabolaiso_shutdown parabolaiso parabolaiso_loop_mnt parabolaiso_pxe_common parabolaiso_pxe_nbd parabolaiso_pxe_http parabolaiso_pxe_nfs parabolaiso_kms block pcmcia filesystems keyboard)
COMPRESSION="xz"
diff --git a/configs/profile-openrc/packages.both b/configs/profile-openrc/packages.both
index 162cc14..b4686f6 100644
--- a/configs/profile-openrc/packages.both
+++ b/configs/profile-openrc/packages.both
@@ -56,3 +56,4 @@ wvdial
xl2tpd
zsh
networkmanager-openrc
+networkmanager-elogind
diff --git a/configs/profile-openrc/root-image/etc/conf.d/agetty.tty1 b/configs/profile-openrc/root-image/etc/conf.d/agetty.tty1
deleted file mode 100644
index b7ff06d..0000000
--- a/configs/profile-openrc/root-image/etc/conf.d/agetty.tty1
+++ /dev/null
@@ -1,11 +0,0 @@
-# Set the baud rate of the terminal line
-baud="38400"
-
-# set the terminal type
-term_type="linux"
-
-# extra options to pass to agetty for this port
-agetty_options="--autologin root --noclear"
-
-# make agetty quiet
-#quiet="no"
diff --git a/configs/profile-openrc/root-image/etc/conf.d/hostname b/configs/profile-openrc/root-image/etc/conf.d/hostname
deleted file mode 100644
index a701f0c..0000000
--- a/configs/profile-openrc/root-image/etc/conf.d/hostname
+++ /dev/null
@@ -1,2 +0,0 @@
-# Set to the hostname of this machine
-hostname="parabolaiso"
diff --git a/configs/profile-openrc/root-image/etc/udev/rules.d/81-dhcpcd.rules b/configs/profile-openrc/root-image/etc/udev/rules.d/81-dhcpcd.rules
deleted file mode 100644
index 970da69..0000000
--- a/configs/profile-openrc/root-image/etc/udev/rules.d/81-dhcpcd.rules
+++ /dev/null
@@ -1 +0,0 @@
-ACTION=="add", SUBSYSTEM=="net", ENV{SYSTEMD_WANTS}="dhcpcd@$name.service"
diff --git a/configs/profile-openrc/root-image/root/customize_root_image.sh b/configs/profile-openrc/root-image/root/customize_root_image.sh
deleted file mode 100755
index f0d3af7..0000000
--- a/configs/profile-openrc/root-image/root/customize_root_image.sh
+++ /dev/null
@@ -1,39 +0,0 @@
-#!/bin/bash
-
-set -e -u
-
-check_dbus() {
- cat /etc/$1|grep dbus
-}
-
-sed -i 's/#\(en_US\.UTF-8\)/\1/' /etc/locale.gen
-locale-gen
-
-ln -sf /usr/share/zoneinfo/UTC /etc/localtime
-
-usermod -s /usr/bin/zsh root
-cp -aT /etc/skel/ /root/
-
-useradd -m -p "" -g users -G "adm,audio,floppy,log,network,rfkill,scanner,storage,optical,power,wheel" -s /usr/bin/zsh parabola
-
-# Create the dbus user if it doesn't exist
-if [[ $(check_dbus group) = "" ]]; then
- echo "Creating dbus group"
- groupadd -g 81 dbus
-fi
-if [[ $(check_dbus passwd) = "" ]]; then
- echo "Creating dbus user"
- useradd -r -s /sbin/nologin -g 81 -u 81 dbus
-fi
-
-chmod 750 /etc/sudoers.d
-chmod 440 /etc/sudoers.d/g_wheel
-
-sed -i "s/#Server/Server/g" /etc/pacman.d/mirrorlist
-
-rc-update add NetworkManager default
-rc-update add dbus default
-rc-update add haveged default
-rc-update add pacman-init default
-
-sed -i "s/_DATE_/${iso_version}/" /etc/motd
diff --git a/configs/profile-openrc/root-image/root/network.html b/configs/profile-openrc/root-image/root/network.html
deleted file mode 100644
index 057e680..0000000
--- a/configs/profile-openrc/root-image/root/network.html
+++ /dev/null
@@ -1,191 +0,0 @@
-Online version: <a href="https://wiki.parabolagnulinux.org/Start_installing">https://wiki.parabolagnulinux.org/Start_installing</a>
-<table id="toc" class="toc"><tr><td><div id="toctitle"><h2>Contents</h2></div>
-<ul>
-<li class="toclevel-1 tocsection-1"><a href="#Start_installing"><span class="tocnumber">1</span> <span class="toctext">Start installing</span></a>
-<ul>
-<li class="toclevel-2 tocsection-2"><a href="#Change_the_language"><span class="tocnumber">1.1</span> <span class="toctext">Change the language</span></a></li>
-<li class="toclevel-2 tocsection-3"><a href="#Establish_an_internet_connection"><span class="tocnumber">1.2</span> <span class="toctext">Establish an internet connection</span></a>
-<ul>
-<li class="toclevel-3 tocsection-4"><a href="#Wired"><span class="tocnumber">1.2.1</span> <span class="toctext">Wired</span></a></li>
-<li class="toclevel-3 tocsection-5"><a href="#Wireless"><span class="tocnumber">1.2.2</span> <span class="toctext">Wireless</span></a></li>
-<li class="toclevel-3 tocsection-6"><a href="#Analog_modem.2C_ISDN_or_PPPoE_DSL"><span class="tocnumber">1.2.3</span> <span class="toctext">Analog modem, ISDN or PPPoE DSL</span></a></li>
-<li class="toclevel-3 tocsection-7"><a href="#Behind_a_proxy_server"><span class="tocnumber">1.2.4</span> <span class="toctext">Behind a proxy server</span></a></li>
-</ul>
-</li>
-</ul>
-</li>
-</ul>
-</td></tr></table>
-<h2> <span class="mw-headline" id="Start_installing"> Start installing </span></h2>
-<p>You are now presented with a shell prompt, automatically logged in as root.
-</p>
-<h3> <span class="mw-headline" id="Change_the_language"> Change the language </span></h3>
-<div style="padding: 5px; margin: 0.50em 0; background-color: #DDFFDD; border: thin solid #BBDDBB"><strong> Tip: </strong>These are optional for the majority of users. Useful only if you plan on writing in your own language in any of the configuration files, if you use diacritical marks in the Wi-Fi password, or if you would like to receive system messages (e.g. possible errors) in your own language.</div>
-<p>By default, the keyboard layout is set to <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">us</span>. If you have a non-<a href="http://en.wikipedia.org/wiki/File:KB_United_States-NoAltGr.svg" class="extiw" title="wikipedia:File:KB United States-NoAltGr.svg">US</a> keyboard layout, run:
-</p>
-<pre># loadkeys <i>layout</i>
-</pre>
-<p>...where <i>layout</i> can be <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">fr</span>, <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">uk</span>, <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">dvorak</span>, <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">be-latin1</span>, etc. See <a href="https://wiki.parabolagnulinux.org/KEYMAP#Keyboard_layouts" title="KEYMAP">here</a> for a comprehensive list.
-</p><p>The font should also be changed, because most languages use more glyphs than the 26 letter <a href="http://en.wikipedia.org/wiki/English_alphabet" class="extiw" title="wikipedia:English alphabet">English alphabet</a>. Otherwise some foreign characters may show up as white squares or as other symbols. Note that the name is case-sensitive, so please type it <i>exactly</i> as you see it:
-</p>
-<pre># setfont Lat2-Terminus16
-</pre>
-<p>By default, the language is set to English (US). If you would like to change the language for the install process <i>(German, in this example)</i>, remove the <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">#</span> in front of the <a rel="nofollow" class="external text" href="http://www.greendesktiny.com/support/knowledgebase_detail.php?ref=EUH-483">locale</a> you want from <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">/etc/locale.gen</span>, along with English (US). Please choose the <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">UTF-8</span> entry.
-</p><p>Use <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">Ctrl+X</span> to exit, and when prompted to save changes, press <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">Y</span> and <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">Enter</span> to use the same filename.
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># nano /etc/locale.gen</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">
-en_US.UTF-8 UTF-8
-de_DE.UTF-8 UTF-8</pre>
-<pre># locale-gen
-# export LANG=de_DE.UTF-8
-</pre>
-<p>Remember, <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">LAlt+LShift</span> activates and deactivates the keymap.
-</p>
-<h3> <span class="mw-headline" id="Establish_an_internet_connection"> Establish an internet connection </span></h3>
-<div style="padding: 5px; margin: 0.50em 0; background-color: #FFDDDD; border: thin solid #DDBBBB"><strong> Warning: </strong>As of v197, udev no longer assigns network interface names according to the wlanX and ethX naming scheme. If you are coming from a different distribution or are reinstalling Parabola and not aware of the new interface naming style, please do not assume that your wireless interface is named wlan0, or that your wired interface is named eth0. You can use the command <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">ip link</span> to discover the names of your interfaces.</div>
-<p>The <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">dhcpcd</span> network daemon starts automatically during boot and it will attempt to start a wired connection. Try to ping a server to see if a connection was established. For example, gnu.org:
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># ping -c 3 gnu.org</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">PING gnu.org (208.118.235.148) 56(84) bytes of data.
-64 bytes from wildebeest.gnu.org (208.118.235.148): icmp_seq=1 ttl=47 time=183 ms
-64 bytes from wildebeest.gnu.org (208.118.235.148): icmp_seq=2 ttl=47 time=168 ms
-64 bytes from wildebeest.gnu.org (208.118.235.148): icmp_seq=3 ttl=47 time=183 ms
-
---- gnu.org ping statistics ---
-3 packets transmitted, 3 received, 0% packet loss, time 2002ms
-rtt min/avg/max/mdev = 168.131/178.357/183.914/7.248 ms</pre>
-<p>If you get a <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">ping: unknown host</span> error, first check if there is an issue with your cable or wireless signal strength. If not, you will need to set up the network manually, as explained below. Once a connection is established move on to <a href="https://wiki.parabolagnulinux.org/Installation_Guide" title="Installation Guide">Installation Guide</a>.
-</p>
-<h4> <span class="mw-headline" id="Wired"> Wired </span></h4>
-<p>Follow this procedure if you need to set up a wired connection via a static IP address.
-</p><p>First, disable the dhcpcd service which was started automatically at boot:
-</p>
-<pre># systemctl stop dhcpcd.service
-</pre>
-<p>Identify the name of your Ethernet interface.
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># ip link</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">
-1: lo: &lt;LOOPBACK,UP,LOWER_UP&gt; mtu 65536 qdisc noqueue state UNKNOWN mode DEFAULT
- link/loopback 00:00:00:00:00:00 brd 00:00:00:00:00:00
-2: enp2s0f0: &lt;BROADCAST,MULTICAST&gt; mtu 1500 qdisc noop state DOWN mode DEFAULT qlen 1000
- link/ether 00:11:25:31:69:20 brd ff:ff:ff:ff:ff:ff
-3: wlp3s0: &lt;BROADCAST,MULTICAST,UP,LOWER_UP&gt; mtu 1500 qdisc mq state UP mode DORMANT qlen 1000
- link/ether 01:02:03:04:05:06 brd ff:ff:ff:ff:ff:ff</pre>
-<p>In this example, the Ethernet interface is <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">enp2s0f0</span>. If you are unsure, your Ethernet interface is likely to start with the letter "e", and unlikely to be "lo" or start with the letter "w". You can also use <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">iwconfig</span> and see which interfaces are not wireless:
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># iwconfig</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">enp2s0f0 no wireless extensions.
-wlp3s0 IEEE 802.11bgn ESSID:"NETGEAR97"
- Mode:Managed Frequency:2.427 GHz Access Point: 2C:B0:5D:9C:72:BF
- Bit Rate=65 Mb/s Tx-Power=16 dBm
- Retry long limit:7 RTS thr:off Fragment thr:off
- Power Management:on
- Link Quality=61/70 Signal level=-49 dBm
- Rx invalid nwid:0 Rx invalid crypt:0 Rx invalid frag:0
- Tx excessive retries:0 Invalid misc:430 Missed beacon:0
-lo no wireless extensions.</pre>
-<p>In this example, neither <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">enp2s0f0</span> nor the loopback device have wireless extensions, meaning <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">enp2s0f0</span> is our Ethernet interface.
-</p><p>You also need to know these settings:
-</p>
-<ul><li> Static IP address.
-</li><li> Subnet mask.
-</li><li> Gateway's IP address.
-</li><li> Name servers' (DNS) IP addresses.
-</li><li> Domain name (unless you are on a local LAN, in which case you can make it up).
-</li></ul>
-<p>Activate the connected Ethernet interface (e.g. <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">enp2s0f0</span>):
-</p>
-<pre># ip link set enp2s0f0 up
-</pre>
-<p>Add the address:
-</p>
-<pre># ip addr add <i>ip_address</i>/<i>subnetmask</i> dev <i>interface_name</i>
-</pre>
-<p>For example:
-</p>
-<pre># ip addr add 192.168.1.2/24 dev enp2s0f0
-</pre>
-<p>For more options, run <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">man ip</span>.
-</p><p>Add your gateway like this, substituting your own gateway's IP address:
-</p>
-<pre># ip route add default via <i>ip_address</i>
-</pre>
-<p>For example:
-</p>
-<pre># ip route add default via 192.168.1.1
-</pre>
-<p>Edit <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">resolv.conf</span>, substituting your name servers' IP addresses and your local domain name:
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># nano /etc/resolv.conf</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">
-nameserver 61.23.173.5
-nameserver 61.95.849.8
-search example.com</pre>
-<div style="padding: 5px; margin: 0.50em 0; background-color: #DDDDFF; border: thin solid #BBBBDD"><strong> Note: </strong>Currently, you may include a maximum of three <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">nameserver</span> lines. In order to overcome this limitation, you can use a locally caching nameserver like <a href="https://wiki.parabolagnulinux.org/Dnsmasq" title="Dnsmasq" class="mw-redirect">Dnsmasq</a>. </div>
-<p>You should now have a working network connection. If you do not, check the detailed <a href="https://wiki.parabolagnulinux.org/Network_Configuration" title="Network Configuration" class="mw-redirect">Network Configuration</a> page.
-</p>
-<h4> <span class="mw-headline" id="Wireless"> Wireless </span></h4>
-<p>Follow this procedure if you need wireless connectivity (Wi-Fi) during the installation process.
-</p><p>First, identify the name of your wireless interface.
-</p>
-<pre style="margin-bottom: 0; border-bottom:none; padding-bottom:0.8em; overflow: auto;"># iw dev</pre>
-<pre style="margin-top: 0; border-top-style:dashed; padding-top: 0.8em; overflow: auto;">phy#0
- Interface wlp3s0
- ifindex 3
- wdev 0x1
- addr 00:21:6a:5e:52:bc
- type managed</pre>
-<p>In this example, <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">wlp3s0</span> is the available wireless interface. If you are unsure, your wireless interface is likely to start with the letter "w", and unlikely to be "lo" or start with the letter "e".
-</p>
-<div style="padding: 5px; margin: 0.50em 0; background-color: #DDDDFF; border: thin solid #BBBBDD"><strong> Note: </strong>If you do not see output similar to this, then your wireless driver has not been loaded. Please see <a href="https://wiki.parabolagnulinux.org/Wireless_Setup" title="Wireless Setup">Wireless Setup</a> for more detailed information.</div>
-<p>Bring the interface up with:
-</p>
-<pre># ip link set wlp3s0 up
-</pre>
-<p>If you get this error message: <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">SIOCSIFFLAGS: No such file or directory</span>, your wireless chipset could need a non-free firmware to function. This is not supported on Parabola. Please see <a href="https://wiki.parabolagnulinux.org/Wireless_Setup" title="Wireless Setup">Wireless Setup</a> if you are unsure if this is the true for your particular chipset.
-</p><p>Next, use <span style="font-family: monospace"><a rel="nofollow" class="external text" href="https://parabolagnulinux.org/packages/?name=netctl">netctl</a></span>'s <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">wifi-menu</span> to connect to a network:
-</p>
-<pre># wifi-menu wlp3s0
-</pre>
-<p>You should now have a working network connection. If you do not, check the detailed <a href="https://wiki.parabolagnulinux.org/Wireless_Setup" title="Wireless Setup">Wireless Setup</a> page.
-</p><p>Alternatively, use <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">iw dev wlp3s0 scan | grep SSID</span> to scan for available networks, then connect to a network with:
-</p>
-<pre># wpa_supplicant -B -i wlp3s0 -c &lt;(wpa_passphrase "<i>ssid</i>" "<i>psk</i>")
-</pre>
-<p>You need to replace <i>ssid</i> with the name of your network (e.g. "Linksys etc...") and <i>psk</i> with your wireless password, <b>leaving the quotes around the network name and password.</b>
-</p><p>Finally, you have to give your interface an IP address. This can be set manually or using the dhcp:
-</p>
-<pre># dhcpcd wlp3s0
-</pre>
-<p>If that does not work, issue the following commands:
-</p>
-<pre># echo 'ctrl_interface=DIR=/run/wpa_supplicant' &gt; /etc/wpa_supplicant.conf
-# wpa_passphrase &lt;ssid&gt; &lt;passphrase&gt; &gt;&gt; /etc/wpa_supplicant.conf
-# ip link set &lt;interface&gt; up # May not be needed as dhcpcd should bring it up but may be needed for wpa_supplicant.
-# wpa_supplicant -B -D nl80211 -c /foobar.conf -i &lt;interface name&gt;
-# dhcpcd -A &lt;interface name&gt;
-</pre>
-<h4> <span class="mw-headline" id="Analog_modem.2C_ISDN_or_PPPoE_DSL"> Analog modem, ISDN or PPPoE DSL </span></h4>
-<p>For xDSL, dial-up and ISDN connections, see <a href="https://wiki.parabolagnulinux.org/Direct_Modem_Connection" title="Direct Modem Connection" class="mw-redirect">Direct Modem Connection</a>.
-</p>
-<h4> <span class="mw-headline" id="Behind_a_proxy_server"> Behind a proxy server </span></h4>
-<p>If you are behind a proxy server, you will need to export the <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">http_proxy</span> and <span style="display:inline-block; background-color:#ebf1f5; padding: 0.1em 0.2em; font-family:monospace; color:#222;">ftp_proxy</span> environment variables. See <a href="https://wiki.parabolagnulinux.org/Proxy_settings" title="Proxy settings" class="mw-redirect">Proxy settings</a> for more information.
-</p>
-<br>
-<p>This page was retrieved from: <a href="https://wiki.parabolagnulinux.org/index.php?title=Start_installing&amp;oldid=5138">https://wiki.parabolagnulinux.org/index.php?title=Start_installing&amp;oldid=5138</a>
-</p>
-<p>Content is available under <a class="external" href="http://www.gnu.org/copyleft/fdl.html">GNU Free Documentation License 1.3 (or at your option, any later version)</a>.
-</p>
-<!--
-NewPP limit report
-Preprocessor visited node count: 462/1000000
-Preprocessor generated node count: 1260/1000000
-Post‐expand include size: 13122/2097152 bytes
-Template argument size: 5931/2097152 bytes
-Highest expansion depth: 7/40
-Expensive parser function count: 0/100
--->
-
-<!-- Saved in parser cache with key wiki_parabolagnulinux_org:pcache:idhash:1857-1!*!0!!en!*!* and timestamp 20130806172112 -->
diff --git a/configs/profile-openrc/build.sh b/configs/profile-openrc/build.sh
index 97fcc35..2f5721c 100755
--- a/configs/profile-openrc/build.sh
+++ b/configs/profile-openrc/build.sh
@@ -8,13 +8,19 @@ iso_version=$(date +%Y.%m.%d)
install_dir=parabola
work_dir=work
out_dir=out
-data_dir=/usr/share/parabolaiso/data
+gpg_key=
arch=$(uname -m)
verbose=""
-pacman_conf=${work_dir}/pacman.conf
script_path=$(readlink -f ${0%/*})
-initcpio_dir=${script_path}/../../parabolaiso/initcpio
+
+# Init system. Options are:
+# - openrc
+# - runit
+# - systemd
+#
+# Default is systemd
+init=openrc
_usage ()
{
@@ -46,56 +52,76 @@ run_once() {
fi
}
# Setup custom pacman.conf with current cache directories.
make_pacman_conf() {
local _cache_dirs
_cache_dirs=($(pacman -v 2>&1 | grep '^Cache Dirs:' | sed 's/Cache Dirs:\s*//g'))
- sed -r "s|^#?\\s*CacheDir.+|CacheDir = $(echo -n ${_cache_dirs[@]})|g" ${script_path}/pacman.conf > ${pacman_conf}
+ sed -r "s|^#?\\s*CacheDir.+|CacheDir = $(echo -n ${_cache_dirs[@]})|g" ${script_path}/pacman.conf > ${work_dir}/pacman.conf
}
# Base installation, plus needed packages (root-image)
make_basefs() {
- setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${pacman_conf}" -D "${install_dir}" init
- setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${pacman_conf}" -D "${install_dir}" -p "memtest86+ mkinitcpio-nfs-utils nbd" install
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -i "${init}" init
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -i "${init}" -p "haveged memtest86+ mkinitcpio-nfs-utils nbd zsh" install
}
-# Additional packages (root-image)
+# Additional packages (airootfs)
make_packages() {
- setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${pacman_conf}" -D "${install_dir}" -p "$(grep -h -v ^# ${script_path}/packages.{both,${arch}})" install
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -p "$(grep -h -v ^# ${script_path}/packages.{both,${arch}})" install
+}
+
+# Needed packages for x86_64 EFI boot
+make_packages_efi() {
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -p "efitools" install
}
# Copy mkinitcpio parabolaiso hooks and build initramfs (root-image)
make_setup_mkinitcpio() {
local _hook
+ mkdir -p ${work_dir}/${arch}/airootfs/etc/initcpio/hooks
+ mkdir -p ${work_dir}/${arch}/airootfs/etc/initcpio/install
for _hook in parabolaiso parabolaiso_shutdown parabolaiso_pxe_common parabolaiso_pxe_nbd parabolaiso_pxe_http parabolaiso_pxe_nfs parabolaiso_loop_mnt; do
- cp ${initcpio_dir}/hooks/${_hook} ${work_dir}/${arch}/root-image/usr/lib/initcpio/hooks
- cp ${initcpio_dir}/install/${_hook} ${work_dir}/${arch}/root-image/usr/lib/initcpio/install
+ cp /usr/lib/initcpio/hooks/${_hook} ${work_dir}/${arch}/airootfs/etc/initcpio/hooks
+ cp /usr/lib/initcpio/install/${_hook} ${work_dir}/${arch}/airootfs/etc/initcpio/install
done
- cp ${initcpio_dir}/install/parabolaiso_kms ${work_dir}/${arch}/root-image/usr/lib/initcpio/install
- cp ${initcpio_dir}/hooks/parabolaiso_shutdown ${work_dir}/${arch}/root-image/usr/lib/initcpio
- cp ${script_path}/mkinitcpio.conf ${work_dir}/${arch}/root-image/etc/mkinitcpio-parabolaiso.conf
- setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${pacman_conf}" -D "${install_dir}" -r 'mkinitcpio -c /etc/mkinitcpio-parabolaiso.conf -k /boot/vmlinuz-linux-libre -g /boot/parabolaiso.img' run
+ sed -i "s|/usr/lib/initcpio/|/etc/initcpio/|g" ${work_dir}/${arch}/airootfs/etc/initcpio/install/parabolaiso_shutdown
+ cp /usr/lib/initcpio/install/parabolaiso_kms ${work_dir}/${arch}/airootfs/etc/initcpio/install
+ cp /usr/lib/initcpio/parabolaiso_shutdown ${work_dir}/${arch}/airootfs/etc/initcpio
+ cp ${script_path}/mkinitcpio.conf ${work_dir}/${arch}/airootfs/etc/mkinitcpio-parabolaiso.conf
+ gnupg_fd=
+ if [[ ${gpg_key} ]]; then
+ gpg --export ${gpg_key} >${work_dir}/gpgkey
+ exec 17<>${work_dir}/gpgkey
+ fi
+ PARABOLAISO_GNUPG_FD=${gpg_key:+17} setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -r 'mkinitcpio -c /etc/mkinitcpio-parabolaiso.conf -k /boot/vmlinuz-linux-libre -g /boot/parabolaiso.img' run
+ if [[ ${gpg_key} ]]; then
+ exec 17<&-
+ fi
}
-# Customize installation (root-image)
-make_customize_root_image() {
- cp -af ${script_path}/root-image ${work_dir}/${arch}
+# Customize installation (airootfs)
+make_customize_airootfs() {
+ cp -af ${script_path}/airootfs ${work_dir}/${arch}
+
+ curl -o ${work_dir}/${arch}/airootfs/etc/pacman.d/mirrorlist 'https://www.parabola.nu/mirrorlist/?country=all&protocol=http&use_mirror_status=on'
- iso_version="${iso_version}" setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${pacman_conf}" -D "${install_dir}" -r '/root/customize_root_image.sh' run
- rm ${work_dir}/${arch}/root-image/root/customize_root_image.sh
+ lynx -dump -nolist 'https://wiki.parabola.nu/index.php/Installation_Guide?action=render' >> ${work_dir}/${arch}/airootfs/root/install.txt
+
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}/${arch}" -C "${work_dir}/pacman.conf" -D "${install_dir}" -r '/root/customize_airootfs.sh' run
+ rm ${work_dir}/${arch}/airootfs/root/customize_airootfs.sh
}
# Prepare kernel/initramfs ${install_dir}/boot/
make_boot() {
mkdir -p ${work_dir}/iso/${install_dir}/boot/${arch}
- cp ${work_dir}/${arch}/root-image/boot/parabolaiso.img ${work_dir}/iso/${install_dir}/boot/${arch}/parabolaiso.img
- cp ${work_dir}/${arch}/root-image/boot/vmlinuz-linux-libre ${work_dir}/iso/${install_dir}/boot/${arch}/vmlinuz
+ cp ${work_dir}/${arch}/airootfs/boot/parabolaiso.img ${work_dir}/iso/${install_dir}/boot/${arch}/parabolaiso.img
+ cp ${work_dir}/${arch}/airootfs/boot/vmlinuz-linux-libre ${work_dir}/iso/${install_dir}/boot/${arch}/vmlinuz
}
# Add other aditional/extra files to ${install_dir}/boot/
make_boot_extra() {
- cp ${work_dir}/${arch}/root-image/boot/memtest86+/memtest.bin ${work_dir}/iso/${install_dir}/boot/memtest
- cp ${work_dir}/${arch}/root-image/usr/share/licenses/common/GPL2/license.txt ${work_dir}/iso/${install_dir}/boot/memtest.COPYING
+ cp ${work_dir}/${arch}/airootfs/boot/memtest86+/memtest.bin ${work_dir}/iso/${install_dir}/boot/memtest
+ cp ${work_dir}/${arch}/airootfs/usr/share/licenses/common/GPL2/license.txt ${work_dir}/iso/${install_dir}/boot/memtest.COPYING
}
# Prepare /${install_dir}/boot/syslinux
@@ -106,26 +132,29 @@ make_syslinux() {
s|%INSTALL_DIR%|${install_dir}|g" ${_cfg} > ${work_dir}/iso/${install_dir}/boot/syslinux/${_cfg##*/}
done
cp ${script_path}/syslinux/splash.png ${work_dir}/iso/${install_dir}/boot/syslinux
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/*.c32 ${work_dir}/iso/${install_dir}/boot/syslinux
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/lpxelinux.0 ${work_dir}/iso/${install_dir}/boot/syslinux
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/memdisk ${work_dir}/iso/${install_dir}/boot/syslinux
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/*.c32 ${work_dir}/iso/${install_dir}/boot/syslinux
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/lpxelinux.0 ${work_dir}/iso/${install_dir}/boot/syslinux
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/memdisk ${work_dir}/iso/${install_dir}/boot/syslinux
mkdir -p ${work_dir}/iso/${install_dir}/boot/syslinux/hdt
- gzip -c -9 ${work_dir}/${arch}/root-image/usr/share/hwdata/pci.ids > ${work_dir}/iso/${install_dir}/boot/syslinux/hdt/pciids.gz
- gzip -c -9 ${work_dir}/${arch}/root-image/usr/lib/modules/*-gnu-*/modules.alias > ${work_dir}/iso/${install_dir}/boot/syslinux/hdt/modalias.gz
+ gzip -c -9 ${work_dir}/${arch}/airootfs/usr/share/hwdata/pci.ids > ${work_dir}/iso/${install_dir}/boot/syslinux/hdt/pciids.gz
+ gzip -c -9 ${work_dir}/${arch}/airootfs/usr/lib/modules/*-gnu-*/modules.alias > ${work_dir}/iso/${install_dir}/boot/syslinux/hdt/modalias.gz
}
# Prepare /isolinux
make_isolinux() {
mkdir -p ${work_dir}/iso/isolinux
sed "s|%INSTALL_DIR%|${install_dir}|g" ${script_path}/isolinux/isolinux.cfg > ${work_dir}/iso/isolinux/isolinux.cfg
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/isolinux.bin ${work_dir}/iso/isolinux/
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/isohdpfx.bin ${work_dir}/iso/isolinux/
- cp ${work_dir}/${arch}/root-image/usr/lib/syslinux/bios/ldlinux.c32 ${work_dir}/iso/isolinux/
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/isolinux.bin ${work_dir}/iso/isolinux/
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/isohdpfx.bin ${work_dir}/iso/isolinux/
+ cp ${work_dir}/${arch}/airootfs/usr/lib/syslinux/bios/ldlinux.c32 ${work_dir}/iso/isolinux/
}
# Prepare /EFI
make_efi() {
mkdir -p ${work_dir}/iso/EFI/boot
+ cp ${work_dir}/x86_64/airootfs/usr/share/efitools/efi/PreLoader.efi ${work_dir}/iso/EFI/boot/bootx64.efi
+ cp ${work_dir}/x86_64/airootfs/usr/share/efitools/efi/HashTool.efi ${work_dir}/iso/EFI/boot/
+
mkdir -p ${work_dir}/iso/loader/entries
cp ${script_path}/efiboot/loader/loader.conf ${work_dir}/iso/loader/
cp ${script_path}/efiboot/loader/entries/uefi-shell-v2-x86_64.conf ${work_dir}/iso/loader/entries/
@@ -135,17 +164,17 @@ make_efi() {
s|%INSTALL_DIR%|${install_dir}|g" \
${script_path}/efiboot/loader/entries/parabolaiso-x86_64-usb.conf > ${work_dir}/iso/loader/entries/parabolaiso-x86_64.conf
- # EFI Shell 2.0 for UEFI 2.3+ ( http://sourceforge.net/apps/mediawiki/tianocore/index.php?title=UEFI_Shell )
- cp ${data_dir}/Shell.efi ${work_dir}/iso/EFI/shellx64_v2.efi
- # EFI Shell 1.0 for non UEFI 2.3+ ( http://sourceforge.net/apps/mediawiki/tianocore/index.php?title=Efi-shell )
- cp ${data_dir}/Shell_Full.efi ${work_dir}/iso/EFI/shellx64_v1.efi
+ # EFI Shell 2.0 for UEFI 2.3+
+ curl -o ${work_dir}/iso/EFI/shellx64_v2.efi https://raw.githubusercontent.com/tianocore/edk2/master/ShellBinPkg/UefiShell/X64/Shell.efi
+ # EFI Shell 1.0 for non UEFI 2.3+
+ curl -o ${work_dir}/iso/EFI/shellx64_v1.efi https://raw.githubusercontent.com/tianocore/edk2/master/EdkShellBinPkg/FullShell/X64/Shell_Full.efi
}
# Prepare efiboot.img::/EFI for "El Torito" EFI boot mode
make_efiboot() {
mkdir -p ${work_dir}/iso/EFI/parabolaiso
- truncate -s 38M ${work_dir}/iso/EFI/parabolaiso/efiboot.img
- mkfs.vfat -n PARABOLAISO_EFI ${work_dir}/iso/EFI/parabolaiso/efiboot.img
+ truncate -s 64M ${work_dir}/iso/EFI/parabolaiso/efiboot.img
+ mkfs.fat -n PARABOLAISO_EFI ${work_dir}/iso/EFI/parabolaiso/efiboot.img
mkdir -p ${work_dir}/efiboot
mount ${work_dir}/iso/EFI/parabolaiso/efiboot.img ${work_dir}/efiboot
@@ -155,6 +184,8 @@ make_efiboot() {
cp ${work_dir}/iso/${install_dir}/boot/x86_64/parabolaiso.img ${work_dir}/efiboot/EFI/parabolaiso/parabolaiso.img
mkdir -p ${work_dir}/efiboot/EFI/boot
+ cp ${work_dir}/x86_64/airootfs/usr/share/efitools/efi/PreLoader.efi ${work_dir}/efiboot/EFI/boot/bootx64.efi
+ cp ${work_dir}/x86_64/airootfs/usr/share/efitools/efi/HashTool.efi ${work_dir}/efiboot/EFI/boot/
mkdir -p ${work_dir}/efiboot/loader/entries
cp ${script_path}/efiboot/loader/loader.conf ${work_dir}/efiboot/loader/
@@ -168,27 +199,20 @@ make_efiboot() {
cp ${work_dir}/iso/EFI/shellx64_v2.efi ${work_dir}/efiboot/EFI/
cp ${work_dir}/iso/EFI/shellx64_v1.efi ${work_dir}/efiboot/EFI/
- umount ${work_dir}/efiboot
+ umount -d ${work_dir}/efiboot
}
-# Copy aitab
-make_aitab() {
- mkdir -p ${work_dir}/iso/${install_dir}
- cp ${script_path}/aitab ${work_dir}/iso/${install_dir}/aitab
-}
-
-# Build all filesystem images specified in aitab (.fs.sfs .sfs)
+# Build airootfs filesystem image
make_prepare() {
- cp -a -l -f ${work_dir}/${arch}/root-image ${work_dir}
+ cp -a -l -f ${work_dir}/${arch}/airootfs ${work_dir}
setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}" -D "${install_dir}" pkglist
- setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}" -D "${install_dir}" prepare
- rm -rf ${work_dir}/root-image
- # rm -rf ${work_dir}/${arch}/root-image (if low space, this helps)
+ setarch ${arch} mkparabolaiso ${verbose} -w "${work_dir}" -D "${install_dir}" ${gpg_key:+-g ${gpg_key}} prepare
+ rm -rf ${work_dir}/airootfs
+ # rm -rf ${work_dir}/${arch}/airootfs (if low space, this helps)
}
# Build ISO
make_iso() {
- mkparabolaiso ${verbose} -w "${work_dir}" -D "${install_dir}" checksum
mkparabolaiso ${verbose} -w "${work_dir}" -D "${install_dir}" -L "${iso_label}" -o "${out_dir}" iso "${iso_name}-${iso_version}-dual.iso"
}
@@ -202,7 +226,7 @@ if [[ ${arch} != x86_64 ]]; then
_usage 1
fi
-while getopts 'N:V:L:D:w:o:vh' arg; do
+while getopts 'N:V:L:D:w:o:g:vh' arg; do
case "${arg}" in
N) iso_name="${OPTARG}" ;;
V) iso_version="${OPTARG}" ;;
@@ -210,6 +234,7 @@ while getopts 'N:V:L:D:w:o:vh' arg; do
D) install_dir="${OPTARG}" ;;
w) work_dir="${OPTARG}" ;;
o) out_dir="${OPTARG}" ;;
+ g) gpg_key="${OPTARG}" ;;
v) verbose="-v" ;;
h) _usage 0 ;;
*)
@@ -223,12 +248,17 @@ mkdir -p ${work_dir}
run_once make_pacman_conf
# Do all stuff for each root-image
for arch in i686 x86_64; do
run_once make_basefs
run_once make_packages
+done
+
+run_once make_packages_efi
+
+for arch in i686 x86_64; do
run_once make_setup_mkinitcpio
- run_once make_customize_root_image
+ run_once make_customize_airootfs
done
for arch in i686 x86_64; do
@@ -242,8 +272,6 @@ run_once make_isolinux
run_once make_efi
run_once make_efiboot
-run_once make_aitab
-
for arch in i686 x86_64; do
run_once make_prepare
done
@@ -46,56 +52,76 @@ run_once() {
fi
}
-# Setup custom pacman.conf with current cache directories.
+# Setup custom pacman.conf with current cache directories and custom mirrorlist.
make_pacman_conf() {
local _cache_dirs
@@ -46,56 +52,76 @@ run_once() {
}
-# Base installation, plus needed packages (root-image)
+# Base installation, plus needed packages (airootfs)
make_basefs() {
@@ -46,56 +52,76 @@ run_once() {
}
-# Copy mkinitcpio parabolaiso hooks and build initramfs (root-image)
+# Copy mkinitcpio parabolaiso hooks and build initramfs (airootfs)
make_setup_mkinitcpio() {
local _hook
@@ -223,12 +248,17 @@ mkdir -p ${work_dir}
run_once make_pacman_conf
-# Do all stuff for each root-image
+# Do all stuff for each airootfs
for arch in i686 x86_64; do
run_once make_basefs